meegkit.asr
===========

.. automodule:: meegkit.asr

   .. rubric:: Functions

   .. autosummary::

      asr_calibrate
      asr_process
      clean_windows

   .. rubric:: Classes

   .. autosummary::

      ASR


